@@ -1,12 +1,13 @@
-C Output from Public domain Ratfor, version 1.0
-      subroutine binsrt(x,y,rw,npd,ind,rind,tx,ty,ilst,nerror)
+C Output from Public domain Ratfor, version 1.03
+      subroutine binsrt(x,y,rw,npd,ind,rind,tx,ty,ilst)
       implicit double precision(a-h,o-z)
       dimension x(npd), y(npd), tx(npd), ty(npd)
       integer rind(npd)
       dimension ind(npd), ilst(npd)
       dimension rw(4)
-      nerror = -1
-      kdiv = 1+dble(npd)**0.25
+      dimension ndi(1)
+      ndi(1) = 0
+      kdiv = int(1+dble(npd)**0.25)
       xkdiv = dble(kdiv)
       xmin = rw(1)
       xmax = rw(2)
@@ -31,11 +32,11 @@ C Output from Public domain Ratfor, version 1.0
       endif
       xt = x(i)
       yt = y(i)
-      ix = 1+(xt-xmin)/dw
+      ix = int(1+(xt-xmin)/dw)
       if(ix.gt.kdiv)then
       ix = kdiv
       endif
-      jy = 1+(yt-ymin)/dh
+      jy = int(1+(yt-ymin)/dh)
       if(jy.gt.kdiv)then
       jy = kdiv
       endif
@@ -60,8 +61,9 @@ C Output from Public domain Ratfor, version 1.0
       endif
 23003 continue
       if(k.ne.npd)then
-      nerror = 2
-      return
+      call intpr("Mismatch between number of points",-1,ndi,0)
+      call intpr("and number of sorted points.",-1,ndi,0)
+      call rexit("Bailing out of binsrt.")
       endif
       do23018 i = 1,npd 
       x(i) = tx(i)
